##  Accessing To-Dos
Where to Access To-Dos | How to Access
---|---
Accessing To-Do Items in the Fact Sheet ![Accessing To-Do Items in the Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiodd0db886bfce4fba8f0949bce4995781_LowRes.png) Accessing To-Do Items in the Fact Sheet | On fact sheets, you can access to-dos from the dedicated To-Dos tab. To-dos also appear in the right-side panel of fact sheets for quick access.
Accessing To-Dos from the Dashboard ![Accessing To-Dos from the Dashboard](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio86ad3a32824d4589b7a8821a72ce6fea_LowRes.png) Accessing To-Dos from the Dashboard |  The My To-Dos panel on the dashboard gives you quick access to all to-dos assigned to you. It provides a clear overview of pending tasks so you can prioritize and complete them without navigating across multiple pages. If the My To-Dos panel is not visible in the dashboard, it is likely because the dashboard has been customized or a custom dashboard has been set as the default by your admin.  To learn how to add the My To-Dos panel or any other available panel, see [Creating and Editing Dashboards![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdocs-eam.leanix.net%2Fdocs%2Fcreating-and-editing-dashboards "https://docs-eam.leanix.net/docs/creating-and-editing-dashboards").
Accessing To-Dos from the Navigation Bar ![Accessing To-Dos from the Navigation Bar](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio6798a5d1c06b4923bb7dd1c693bbd74f_LowRes.png) Accessing To-Dos from the Navigation Bar | You can access To-Dos from the navigation bar by selecting More and then choosing To-Dos.


### Accessing the To-Do Items in the Administration Area
To allow governance and track the completion of to-dos, admins have the additional possibility to access the list of all to-dos of a workspace centrally in one place from the administration area. You can search, sort, and filter the items and modify any of the to-do items. To learn more, see [Managing To-Dos](https://help.sap.com/docs/leanix/ea/to-dos-administration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275dbdde7a4410148637f298598afe49__managing_to-dos).
